def init_envconf():
    return """
#ENVIRONEMENT CONF DO NOT PUSH 
CLIENT='UNKNOWN'
SRC_DOMAIN='UNKNOWN'
SRC_TENANTID='UNKNOWN'
SRC_TENANTNAME='UNKNOWN'
SRC_USERNAME='UNKNOWN'
SRC_PASSWORD='UNKNOWN'
TRG_DOMAIN='UNKNOWN'
TRG_TENANTID='UNKNOWN'
TRG_TENANTNAME='UNKNOWN'
TRG_USERNAME='UNKNOWN'
TRG_PASSWORD='UNKNOWN'
"""